summaryrefslogtreecommitdiff
path: root/sql/item_subselect.h
diff options
context:
space:
mode:
authorbell@sanja.is.com.ua <>2002-10-13 14:25:16 +0300
committerbell@sanja.is.com.ua <>2002-10-13 14:25:16 +0300
commitd9f998164d6612da1b5a32858de7b9d34929036c (patch)
treee50e70457b66196d793e32095a4bb48595e9bae3 /sql/item_subselect.h
parentf6d9e96fbcc26a821e7d304ab18364fa1ab01a08 (diff)
downloadmariadb-git-d9f998164d6612da1b5a32858de7b9d34929036c.tar.gz
fixed bug of multi-level EXPLAIN
Diffstat (limited to 'sql/item_subselect.h')
-rw-r--r--sql/item_subselect.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sql/item_subselect.h b/sql/item_subselect.h
index 79b6b3a4292..33f82982708 100644
--- a/sql/item_subselect.h
+++ b/sql/item_subselect.h
@@ -179,8 +179,9 @@ public:
class subselect_single_select_engine: public subselect_engine
{
- my_bool executed; /* simple subselect is executed */
+ my_bool prepared; /* simple subselect is prepared */
my_bool optimized; /* simple subselect is optimized */
+ my_bool executed; /* simple subselect is executed */
st_select_lex *select_lex; /* corresponding select_lex */
JOIN * join; /* corresponding JOIN structure */
public: